@@ -30,9 +30,6 @@ class PublisherDescriptionOption(schema.DictOption):
                 error_dir=schema.StringOption(
                     help="For datedir: the path to write the oopses to.",
                     ),
-                instance_id=schema.StringOption(
-                    help="For datedir: an identifier for this instance.",
-                    ),
                 host=schema.StringOption(
                     help="For amqp: the host:port for the amqp broker.",
                     ),
